@@ -2189,7 +2189,7 @@ class Plot(object):
 
     return self._closefig(fig)
 
-  def plot_line_origin(self,model,lineIdents,field,label="value",boxcolors=None,showBox=True,showRadialLines=True,boxlinewidths=1.5,
+  def plot_line_origin(self,model,lineIdents,field,label="value",boxcolors=None,showBox=True,showRadialLines=True,showztauD1=True,boxlinewidths=1.5,
                        boxlinestyles=None,boxhatches=None,lineLabels=None,showLineLabels=True,lineLabelsFontsize=6.0,lineLabelsAlign="left",zlog=True,
                 zlim=[None,None],zr=True,clevels=None,clabels=None,contour=False,
                 extend="neither",oconts=None,nbins=70,
@@ -2299,7 +2299,8 @@ class Plot(object):
       ax=fig.axes[0]
 
     # show the full emitting layer as function of radius
-    if showRadialLines:
+    # maybe this slows down the pl
+    if showRadialLines or showztauD1:
       iest=0
       r=model.x[:,0]
       for lesti in lestimates:
@@ -2314,20 +2315,28 @@ class Plot(object):
         else:
           lsrad=":"
 
-        ax.plot(r,z15,color=boxcolors[iest],linestyle=lsrad,linewidth=1.0)
-        ax.plot(r,z85,color=boxcolors[iest],linestyle=lsrad,linewidth=1.0)
-        if boxhatches is not None:
-          ax.fill_between(r,z15,z85,edgecolor=boxcolors[iest],hatch=boxhatches[iest],facecolor="none",linewidth=0.0)
+        if showRadialLines:
+          ax.plot(r,z15,color=boxcolors[iest],linestyle=lsrad,linewidth=1.0)
+          ax.plot(r,z85,color=boxcolors[iest],linestyle=lsrad,linewidth=1.0)
+          if boxhatches is not None:
+            ax.fill_between(r,z15,z85,edgecolor=boxcolors[iest],hatch=boxhatches[iest],facecolor="none",linewidth=0.0)
+
+        # can be None just check the first entry
+        if showztauD1 and lesti.rInfo[0].ztauD1 is not None:
+          ztauD1=[rinf.ztauD1 for rinf in lesti.rInfo]
+          if zr: ztauD1=ztauD1/r
+
+          ax.plot(r,ztauD1,color=boxcolors[iest],linestyle="--",linewidth=1.0)
 
         iest+=1
 
     if showLineLabels:
       ibox=0
-      for idline in lineIdents:
+      for idline,lesti in zip(lineIdents,lestimates):
         if lineLabels is not None:
           label=lineLabels[ibox]
         else:
-          label="$"+spnToLatex(idline[0])+"$ "+str(idline[1])
+          label="$"+spnToLatex(idline[0])+"$ "+("{:10.2f}".format(lesti.wl)).strip()+r" $\mu$m"
 
         # FIXME: quick and dirty, ref fontsize =6.0
         vpos=ibox/(18.0-(lineLabelsFontsize/6.0-1.0)*12.0)
