@@ -700,17 +700,27 @@ class PlotCasasim(object):
 
     return self._closefig(fig)
 
-  def plot_pv(self,image,zlim=[None,None],ylim=[None,None],**kwargs):
+  def plot_pv(self,image,zlim=[None,None],ylim=[None,None],mJy=False,**kwargs):
     """
     Plots a position-velocity diagram.
+
+
+    .. todo::
+      * it is not possible to set the xlim (offset) coordinate in arcsec. Requires likely the conversion form pix to arcsec or vice versa
+
     """
 
     if image is None: return
 
+    if mJy:
+      data=image.data*1000.
+    else:
+      data=image.data
+
     vmin=zlim[0]
     vmax=zlim[1]
-    if vmin is None: vmin=numpy.nanmin(image.data)
-    if vmax is None: vmax=numpy.nanmax(image.data)
+    if vmin is None: vmin=numpy.nanmin(data)
+    if vmax is None: vmax=numpy.nanmax(data)
 
   # FIXME: stolen from here ... https://github.com/astropy/astropy/issues/4529
     # mabe not the best way to go
@@ -755,7 +765,7 @@ class PlotCasasim(object):
                            loc=3,pad=0.5,borderpad=0.4,frameon=False)
     ax.add_artist(ar)
 
-    im=ax.imshow(image.data,cmap="inferno",vmin=vmin,vmax=vmax,aspect='auto',origin="lower")
+    im=ax.imshow(data,cmap="inferno",vmin=vmin,vmax=vmax,aspect='auto',origin="lower")
     ax.set_xticks(xticks)
     ax.set_xticklabels(map(str,xticklabels))
     ax.set_yticks(yticks)
@@ -779,9 +789,12 @@ class PlotCasasim(object):
     CB=fig.colorbar(im,ax=ax,pad=0.02,
                     format="%5.2f",fraction=0.04)
     CB.set_ticks(ticks)
-    CB.set_label("[Jy/beam]")
+    if mJy:
+      CB.set_label("[mJy/beam]")
+    else:
+      CB.set_label("[Jy/beam]")
 
-    self._closefig(fig)
+    return self._closefig(fig)
 
   def plot_specprof(self,specprof,models=None,xlim=[None,None],modelNames=None,**kwargs):
     """
