@@ -13,7 +13,7 @@ import pandas as pd
 from scipy.constants import h,c,k
 from adjustText import adjust_text
 import matplotlib.pyplot as plt
-from prodimopy.read_slab import slab_data,slab
+from prodimopy.read_slab import slab_data,slab,slab1D
 import matplotlib.colors as mcolors
 import matplotlib.cm as cm
 sci_c = c*1.00
@@ -232,11 +232,14 @@ def plot_lines(dat, normalise = False, fig=None, ax=None, overplot=False, c=None
                 
     if isinstance(offset,float) or isinstance(offset,int):
         for i in range(len(dat)):
-            offset_list.append(offset*i)
+            offset_list.append(offset*(i+1))
     elif isinstance(offset,list):
         offset_list = offset
+    elif isinstance(offset,np.ndarray):
+        offset_list.append(offset)
     else:
-        raise ValueError('offset takes only int, float or list of int or float')
+        raise ValueError('offset takes only int, float or list of int or float or numpy array')
+
     
     if isinstance(scaling,float) or isinstance(scaling,int):
         for i in range(len(dat)):
@@ -314,7 +317,7 @@ def _basic_line_plot(x,y,normalise=False,fig=None, ax=None, scaling=1, figsize=N
     return(fig,ax)
 
 
-def plot_spectra(dat, normalise = False, fig=None, ax=None, overplot=False, add=False, cmap=None, colors=None, style='step', figsize=None, NLTE=False, label='', lw=1, c=None, scaling=1,sampling=1,offset=0):
+def plot_spectra(dat, normalise = False, fig=None, ax=None, overplot=False, add=False, cmap=None, colors=None, style='step', figsize=None, NLTE=False, label='', lw=1, c=None, scaling=1, sampling=1, offset=0, overlap=False):
     """
     This function plots convolved spectra (erg/s/cm2/sr)
     """
@@ -345,11 +348,14 @@ def plot_spectra(dat, normalise = False, fig=None, ax=None, overplot=False, add=
                 
     if isinstance(offset,float) or isinstance(offset,int):
         for i in range(len(dat)):
-            offset_list.append(offset*i)
+            offset_list.append(offset*(i+1))
     elif isinstance(offset,list):
         offset_list = offset
+    elif isinstance(offset,np.ndarray):
+        offset_list.append(offset)
     else:
-        raise ValueError('offset takes only int, float or list of int or float')
+        raise ValueError('offset takes only int, float or list of int or float or numpy array')
+
     
     if isinstance(scaling,float) or isinstance(scaling,int):
         for i in range(len(dat)):
@@ -367,22 +373,44 @@ def plot_spectra(dat, normalise = False, fig=None, ax=None, overplot=False, add=
     scalarMap = cm.ScalarMappable(norm=cNorm, cmap=jet)   
     
     for d in dat:
-        if d.convWavelength is None:
-            raise ValueError('The model is not convolved, please use .convolve() method')
-    add_wave = dat[0].convWavelength
-    add_flux = add_wave*0.0
+        if not overlap:
+            if d.convWavelength is None:
+                raise ValueError('The model is not convolved, please use .convolve() method')
+        else:
+            if d.convOverlapFreq is None:
+                raise ValueError('The model is not convolved, please use .convolve_overlap() method')
+        
+    if not overlap:
+        add_wave = dat[0].convWavelength
+        add_flux = add_wave*0.0
+    else:
+        add_wave = sci_c/dat[0].convOverlapFreq*1e-3
+        add_flux = add_wave*0.0
     if add:
-        for i,d in enumerate(dat):
-            if not np.array_equal(add_wave, d.convWavelength):
-                raise ValueError('Convolved wavelength grid not same for molecules within a model')
-        if NLTE:
+        if not overlap:
             for i,d in enumerate(dat):
-                add_flux+=d.convNLTEflux
+                if not np.array_equal(add_wave, d.convWavelength):
+                    raise ValueError('Convolved wavelength grid not same for molecules within a model')
+            if NLTE:
+                for i,d in enumerate(dat):
+                    add_flux+=d.convNLTEflux
+            else:
+                for i,d in enumerate(dat):
+                    add_flux+=d.convLTEflux
+            convRR = dat[0].convR
         else:
             for i,d in enumerate(dat):
-                add_flux+=d.convLTEflux
+                if not np.array_equal(add_wave, d.convOverlapFreq):
+                    raise ValueError('Convolved wavelength grid not same for molecules within a model')
+            if NLTE:
+                for i,d in enumerate(dat):
+                    add_flux+=d.convOverlapNLTE
+            else:
+                for i,d in enumerate(dat):
+                    add_flux+=d.convOverlapLTE
+            convRR = dat[0].convOverlapR
         fig,ax = _get_set_fig(ax,fig,figsize)
-        fig,ax = _basic_spectra_plot(add_wave, add_flux,convR = dat[0].convR, sampling=sampling, scaling=scaling, normalise=normalise, fig=fig, ax=ax, style=style, figsize=figsize, label=label, color=c,lw=lw, where='mid')
+        fig,ax = _basic_spectra_plot(add_wave, add_flux,convR = convRR, sampling=sampling, scaling=scaling, normalise=normalise, fig=fig, ax=ax, style=style, figsize=figsize, label=label, color=c,lw=lw, where='mid',offset=offset)
         return(fig,ax)
     
     if overplot:
@@ -420,35 +448,135 @@ def plot_spectra(dat, normalise = False, fig=None, ax=None, overplot=False, add=
             
     if overplot:
         for i,d in enumerate(dat):
-            add_wave = d.convWavelength
-            if NLTE:
-                add_flux=d.convNLTEflux
+            if not overlap:
+                add_wave = d.convWavelength
+                if NLTE:
+                    add_flux=d.convNLTEflux
+                else:
+                    add_flux=d.convLTEflux
+                convRR = dat[i].convR
             else:
-                add_flux=d.convLTEflux
-            fig_list[0],ax_list[0] = _basic_spectra_plot(add_wave, add_flux,convR= dat[i].convR,sampling=sampling, scaling=scaling_list[i], offset=offset_list[i],  normalise=normalise, fig=fig_list[0], ax=ax_list[0], style=style, figsize=figsize, label=label_list[i], color=color_list[i],lw=lw, where='mid')
+                add_wave = sci_c/d.convOverlapFreq*1e-3
+                if NLTE:
+                    add_flux=d.convOverlapNLTE
+                else:
+                    add_flux=d.convOverlapLTE
+                convRR = dat[i].convOverlapR
+            fig_list[0],ax_list[0] = _basic_spectra_plot(add_wave, add_flux,convR= convRR,sampling=sampling, scaling=scaling_list[i], offset=offset_list[i],  normalise=normalise, fig=fig_list[0], ax=ax_list[0], style=style, figsize=figsize, label=label_list[i], color=color_list[i],lw=lw, where='mid')
         return(fig_list[0],ax_list[0])
     else:
         for i,d in enumerate(dat):
-            add_wave = d.convWavelength
-            if NLTE:
-                add_flux=d.convNLTEflux
+            if not overlap:
+                add_wave = d.convWavelength
+                if NLTE:
+                    add_flux=d.convNLTEflux
+                else:
+                    add_flux=d.convLTEflux
+                convRR = dat[i].convR
             else:
-                add_flux=d.convLTEflux
-            fig_list[i],ax_list[i] = _basic_spectra_plot(add_wave, add_flux,convR= dat[i].convR,sampling=sampling, scaling=scaling_list[i], offset=offset_list[i],  normalise=normalise, fig=fig_list[i], ax=ax_list[i], style=style, figsize=figsize, label=label_list[i], color=color_list[i],lw=lw, where='mid')
+                add_wave = sci_c/d.convOverlapFreq*1e-3
+                if NLTE:
+                    add_flux=d.convOverlapNLTE
+                else:
+                    add_flux=d.convOverlapLTE
+                convRR = dat[i].convOverlapR
+            fig_list[i],ax_list[i] = _basic_spectra_plot(add_wave, add_flux,convR= convRR,sampling=sampling, scaling=scaling_list[i], offset=offset_list[i],  normalise=normalise, fig=fig_list[i], ax=ax_list[i], style=style, figsize=figsize, label=label_list[i], color=color_list[i],lw=lw, where='mid')
         if axx_len>1:
             return(fig_list[0],np.array(ax_list))
         else:
             return([(fig,ax) for (fig,ax) in zip(fig_list,ax_list)])
             
+def plot_1D_spectra(dat, convolved = False, R=None, normalise = False, fig=None, ax=None, style='step', figsize=None, label='', lw=1, c=None, scaling=1, sampling=1, offset=0):
+    """
+    This function plots spectra of 1D slab models (erg/s/cm2/sr)
+    """
+
+    if not isinstance(dat,slab1D):
+        raise ValueError('Wrong input 1D slab data')
+
+    if ((not convolved) or (dat.convWavelength is None)) and (R is None):
+        Flux = dat.flux
+        Wavelength = sci_c/dat.frequency*1e-3
+        convR = dat.R
+    elif not (R is None):
+        tempFlux = dat.conv_flux
+        temp_R = dat.convR
+        temp_Freq = dat.convFrequency
+        temp_Wave = dat.convWavelength
+        dat.convolve(R=R,verbose=False)
+        Flux = dat.flux
+        Wavelength = sci_c/dat.frequency*1e-3
+        convR = R
+        dat.conv_flux = tempFlux
+        dat.convR = temp_R
+        dat.convFrequency = temp_Freq
+        dat.convWavelength = temp_Wave
+    elif not ((not convolved) or (dat.convWavelength is None)):
+        Flux = dat.conv_flux
+        Wavelength = dat.convWavelength
+        convR = dat.convR
+    else:
+        raise ValueError('The model is not convolved, please set convolved=False or use .convolve() method or specify a resolving power to plot')
+
+    fig,ax = _get_set_fig(ax,fig,figsize)
+    fig,ax = _basic_spectra_plot(Wavelength, Flux,convR = convR, sampling=sampling, scaling=scaling, normalise=normalise, fig=fig, ax=ax, style=style, figsize=figsize, label=label, color=c,lw=lw, where='mid',offset=offset)
+    return(fig,ax)
+
+def plot_1D_structure(dat, figsize=None,grid_point=False):
+    """
+    This function plots structure of 1D slab models
+    """
+    fig,ax = plt.subplots(1,5,figsize=figsize,sharey=True)
+    if grid_point:
+        x_array = [i+1 for i in range(dat.Ngrid)]
+        ax[0].set_xlabel('Grid points (i)')
+    else:
+        x_array = np.cumsum(dat.grid['dz'])
+        ax[0].set_xlabel('z [au]')
+    ax[0].plot(dat.grid['dz'],   x_array,c='k')
+    ax[0].set_xlabel('dz')
+    ax[0].set_xscale('log')
+    
+    ax[1].plot(dat.grid['vturb'],x_array,c='k')
+    ax[1].set_xlabel('v$_{turb}$ [km/s]')
+
+    ax[2].plot(dat.grid['nd'],   x_array,c='k')
+    ax[2].set_xlabel('n$_d$ [cm$-3$]')
+    ax[2].set_xscale('log')
+    
+    ax[3].plot(dat.grid['Td'],   x_array,c='k')
+    for i in range(dat.Nspecies): 
+        ax[3].plot(dat.grid['Tg_'+dat.species[i]],x_array,c=cm.viridis(i/dat.Nspecies),ls='solid',label=dat.species[i])
+    ax[3].set_xlabel('T [K]')
+    ax[3].legend(loc='upper left')
+    
+    array = dat.grid['nH2']+dat.grid['nHI']+dat.grid['nHII']+dat.grid['nHe']+dat.grid['nelec']
+    for i in range(dat.Nspecies):
+        array += dat.grid['n'+dat.species[i]]
+    ax[4].plot(array,x_array,c='k')
+    ax[4].plot(dat.grid['nH2'],x_array,c='r',ls='solid',label='nH2')
+    ax[4].plot(dat.grid['nHI'],x_array,c='r',ls='dashed',label='nHI')
+    ax[4].plot(dat.grid['nHII'],x_array,c='r',ls='dotted',label='nHII')
+    ax[4].plot(dat.grid['nHe'],x_array,c='r',ls='dashdot',label='nHe')
+    ax[4].plot(dat.grid['nelec'],x_array,c='r',ls=(0, (3, 1, 1, 1, 1, 1)),label='nelec')
+    for i in range(dat.Nspecies): 
+        ax[4].plot(dat.grid['n'+dat.species[i]],x_array,c=cm.viridis(i/dat.Nspecies),ls='solid',label=dat.species[i])
+    ax[4].legend(loc='upper left')
+    ax[4].set_xscale('log')
+    ax[4].set_xlabel('n [cm$^-3$]')
+
+    
+
+    return(fig,ax)
         
-def _basic_spectra_plot(x, y, convR,sampling=1,normalise=False, fig=None, ax=None, scaling=1, offset=0.0, figsize=None, label='', color='k', style='step', lw=1, where='post'):
+def _basic_spectra_plot(x, y, convR,sampling=1,normalise=False, fig=None, ax=None, scaling=1, offset=0.0, figsize=None, label='', color='k', style='step', lw=1, where='post', R=1e6):
     if x is None or y is None:
         raise ValueError('x or y is None, mostly the data is not convolved. Please use .convolve() method first')
     fig,ax = _get_set_fig(ax,fig,figsize)
     if normalise:
         y = y/np.amax(y)
     y = y*scaling+offset
-    ind = int(1e6/convR/sampling)
+    ind = int(R/convR/sampling)
     if ind>len(y): ind = len(y)
     if ind == 0:   ind = 1
     if style=='step':
@@ -456,5 +584,5 @@ def _basic_spectra_plot(x, y, convR,sampling=1,normalise=False, fig=None, ax=Non
     else:
         ax.plot(x[::ind], y[::ind], lw=lw, label = label, color=color)
     ax.set_xlabel('Wavelength [microns]')
-    ax.legend()
+    # ax.legend()
     return(fig,ax)
\ No newline at end of file
